package metaData;

import java.sql.Connection;
import java.sql.DatabaseMetaData;
import java.sql.DriverManager;
import java.sql.SQLException;


public class JDBCMeta {

  public static void main(String[] av) {
    try {
         
      Class.forName ("com.mysql.jdbc.Driver");


      System.out.println("Kapcsolatobjektum lekérése");
      Connection conn = DriverManager.getConnection (
        "jdbc:mysql://localhost:3306/jdbcTest",
        "root", "root");  // user, passwd

      // DatabaseMetaData lekerese, melynek segitsegevel lekerdezhetjuk 
      // az adatbazis tablainak nevet
      DatabaseMetaData meta = conn.getMetaData();

      System.out.println(meta.getDatabaseProductName() + " adatbázist használunk.");
      System.out
          .println("Verzió:  " + meta.getDatabaseProductVersion());

      int txisolation = meta.getDefaultTransactionIsolation();
      System.out.println("Az adatbázis alapértelmezett tranzakció-elszigetelési szintje "
          + txisolation + " ("
          + transactionIsolationToString(txisolation) + ").");

      conn.close();

      System.out.println("Kész!");

    }  catch (ClassNotFoundException e) {
      System.out.println("Hiba a driver betöltésénél " + e);
    } catch (SQLException ex) {
      System.out.println("Sikertelen kapcsolódás az adatbázishoz:");
      System.out.println(ex);
    }
  }

  /**
   * a (java.sql.Connection-ban definiált) TransactionIsolation int értéket átalakítja
   * a megfelelő karaktersorrá.
   */
  public static String transactionIsolationToString(int txisolation) {
    switch (txisolation) {
    case Connection.TRANSACTION_NONE:
      // a tranzakciok nincsenek tamogatva.
      return "TRANSACTION_NONE";
    case Connection.TRANSACTION_READ_UNCOMMITTED:
      // Mindhárom jelenség felléphet:
      //piszkos olvasás (dirty read) - a tranzakció írásai a commit esemény előtt is olvashatóak
      //megismételhetetlen olvasás (nonrepeatable read) - "A" tranzakció olvas egy sort, "B" tranzakció megváltoztatja, "A" tranzakció újra olvassa ugyanazt a megváltozott sort
      //fantom olvasás (phantom read) - "A" tranzakció olvassa az összes sort amely a WHERE feltételben van
      //								"B" tranzakció beilleszt egy sort amely megfelel ugyanennek a feltételnek, 
      //								"A" tranzakció újraértékeli a kifejezést és beveszi a fantom sort is
      return "TRANSACTION_NONE";
    case Connection.TRANSACTION_READ_COMMITTED:
      // piszkos olvasás nem; megismételhetetlen olvasás és
      // fantom olvasás lehetséges.
      return "TRANSACTION_READ_COMMITTED";
    case Connection.TRANSACTION_REPEATABLE_READ:
      // piszkos olvasás és megismételhetetlen olvasás nem,
      // fantom olvasás lehetséges.
      return "TRANSACTION_REPEATABLE_READ";
    case Connection.TRANSACTION_SERIALIZABLE:
      // Egyik jelenség sem léphet fel; leglassúbb!
      return "TRANSACTION_SERIALIZABLE";
    default:
      throw new IllegalArgumentException(txisolation
          + " not a valid TX_ISOLATION");
    }
  }
}


           
       